@@ -5,15 +5,17 @@ mf module.  Contains the ModflowGlobal, ModflowList, and Modflow classes.
 """
 
 import os
-import flopy
+import warnings
 from inspect import getfullargspec
+
+import flopy
+
+from ..discretization.modeltime import ModelTime
+from ..discretization.structuredgrid import StructuredGrid
+from ..discretization.unstructuredgrid import UnstructuredGrid
 from ..mbase import BaseModel
 from ..pakbase import Package
 from ..utils import mfreadnam
-from ..discretization.structuredgrid import StructuredGrid
-from ..discretization.unstructuredgrid import UnstructuredGrid
-from ..discretization.grid import Grid
-from flopy.discretization.modeltime import ModelTime
 from .mfpar import ModflowPar
 
 
@@ -24,7 +26,7 @@ class ModflowGlobal(Package):
     """
 
     def __init__(self, model, extension="glo"):
-        Package.__init__(self, model, extension, "GLOBAL", 1)
+        super().__init__(model, extension, "GLOBAL", 1)
         return
 
     def __repr__(self):
@@ -42,7 +44,7 @@ class ModflowList(Package):
     """
 
     def __init__(self, model, extension="list", unitnumber=2):
-        Package.__init__(self, model, extension, "LIST", unitnumber)
+        super().__init__(model, extension, "LIST", unitnumber)
         return
 
     def __repr__(self):
@@ -111,7 +113,7 @@ class Modflow(BaseModel):
         model_ws=".",
         external_path=None,
         verbose=False,
-        **kwargs
+        **kwargs,
     ):
         super().__init__(
             modelname,
@@ -120,7 +122,7 @@ class Modflow(BaseModel):
             model_ws,
             structured=structured,
             verbose=verbose,
-            **kwargs
+            **kwargs,
         )
         self.version_types = {
             "mf2k": "MODFLOW-2000",
@@ -155,11 +157,7 @@ class Modflow(BaseModel):
 
         if external_path is not None:
             if os.path.exists(os.path.join(model_ws, external_path)):
-                print(
-                    "Note: external_path "
-                    + str(external_path)
-                    + " already exists"
-                )
+                print(f"Note: external_path {external_path} already exists")
             else:
                 os.makedirs(os.path.join(model_ws, external_path))
         self.external_path = external_path
@@ -183,7 +181,6 @@ class Modflow(BaseModel):
             "pval": flopy.modflow.ModflowPval,
             "bas6": flopy.modflow.ModflowBas,
             "dis": flopy.modflow.ModflowDis,
-            "disu": flopy.modflow.ModflowDisU,
             "bcf6": flopy.modflow.ModflowBcf,
             "lpf": flopy.modflow.ModflowLpf,
             "hfb6": flopy.modflow.ModflowHfb,
@@ -208,7 +205,6 @@ class Modflow(BaseModel):
             "pcgn": flopy.modflow.ModflowPcgn,
             "nwt": flopy.modflow.ModflowNwt,
             "pks": flopy.modflow.ModflowPks,
-            "sms": flopy.modflow.ModflowSms,
             "sfr": flopy.modflow.ModflowSfr2,
             "lak": flopy.modflow.ModflowLak,
             "gage": flopy.modflow.ModflowGage,
@@ -233,24 +229,11 @@ class Modflow(BaseModel):
 
     def __repr__(self):
         nrow, ncol, nlay, nper = self.get_nrow_ncol_nlay_nper()
-        if nrow is not None:
-            # structured case
-            s = (
-                "MODFLOW {} layer(s) {} row(s) {} column(s) "
-                "{} stress period(s)".format(nlay, nrow, ncol, nper)
-            )
-        else:
-            # unstructured case
-            nodes = ncol.sum()
-            nodelay = " ".join(str(i) for i in ncol)
-            print(nodelay, nlay, nper)
-            s = (
-                "MODFLOW unstructured\n"
-                "  nodes = {}\n"
-                "  layers = {}\n"
-                "  periods = {}\n"
-                "  nodelay = {}\n".format(nodes, nlay, nper, ncol)
-            )
+        # structured case
+        s = (
+            "MODFLOW {} layer(s) {} row(s) {} column(s) "
+            "{} stress period(s)".format(nlay, nrow, ncol, nper)
+        )
         return s
 
     #
@@ -331,7 +314,7 @@ class Modflow(BaseModel):
                 yoff=self._modelgrid.yoffset,
                 angrot=self._modelgrid.angrot,
                 nlay=self.dis.nlay,
-                laycbd=self.dis.laycbd,
+                laycbd=self.dis.laycbd.array,
             )
 
         # resolve offsets
@@ -455,10 +438,10 @@ class Modflow(BaseModel):
 
         if self.version == "mf2k":
             for i in range(len(self.glo.extension)):
-                self.glo.file_name[i] = self.name + "." + self.glo.extension[i]
+                self.glo.file_name[i] = f"{self.name}.{self.glo.extension[i]}"
 
         for i in range(len(self.lst.extension)):
-            self.lst.file_name[i] = self.name + "." + self.lst.extension[i]
+            self.lst.file_name[i] = f"{self.name}.{self.lst.extension[i]}"
 
     def write_name_file(self):
         """
@@ -467,9 +450,9 @@ class Modflow(BaseModel):
         """
         fn_path = os.path.join(self.model_ws, self.namefile)
         f_nam = open(fn_path, "w")
-        f_nam.write("{}\n".format(self.heading))
-        f_nam.write("#" + str(self.modelgrid))
-        f_nam.write("; start_datetime:{0}\n".format(self.start_datetime))
+        f_nam.write(f"{self.heading}\n")
+        f_nam.write(f"#{self.modelgrid!s}")
+        f_nam.write(f"; start_datetime:{self.start_datetime}\n")
         if self.version == "mf2k":
             if self.glo.unit_number[0] > 0:
                 f_nam.write(
@@ -501,13 +484,11 @@ class Modflow(BaseModel):
             if o:
                 replace_text = " REPLACE"
             if b:
-                line = "DATA(BINARY)   {:5d}  {}{}\n".format(
-                    u, f, replace_text
-                )
+                line = f"DATA(BINARY)   {u:5d}  {f}{replace_text}\n"
 
                 f_nam.write(line)
             else:
-                f_nam.write("DATA           {:5d}  {}\n".format(u, f))
+                f_nam.write(f"DATA           {u:5d}  {f}\n")
 
         # write the output files
         for u, f, b in zip(
@@ -516,9 +497,9 @@ class Modflow(BaseModel):
             if u == 0:
                 continue
             if b:
-                f_nam.write("DATA(BINARY)   {:5d}  {} REPLACE\n".format(u, f))
+                f_nam.write(f"DATA(BINARY)   {u:5d}  {f} REPLACE\n")
             else:
-                f_nam.write("DATA           {:5d}  {}\n".format(u, f))
+                f_nam.write(f"DATA           {u:5d}  {f}\n")
 
         # close the name file
         f_nam.close()
@@ -619,20 +600,11 @@ class Modflow(BaseModel):
                     if v.lower() == "save budget":
                         savebud = True
         except Exception as e:
-            print(
-                "error reading output filenames "
-                + "from OC package: {}".format(str(e))
-            )
+            print(f"error reading output filenames from OC package: {e!s}")
 
-        self.hpth = os.path.join(
-            self.model_ws, "{}.{}".format(self.name, self.hext)
-        )
-        self.dpth = os.path.join(
-            self.model_ws, "{}.{}".format(self.name, self.dext)
-        )
-        self.cpth = os.path.join(
-            self.model_ws, "{}.{}".format(self.name, self.cext)
-        )
+        self.hpth = os.path.join(self.model_ws, f"{self.name}.{self.hext}")
+        self.dpth = os.path.join(self.model_ws, f"{self.name}.{self.dext}")
+        self.cpth = os.path.join(self.model_ws, f"{self.name}.{self.cext}")
 
         hdObj = None
         ddObj = None
@@ -657,7 +629,7 @@ class Modflow(BaseModel):
                     text="subsidence",
                 )
         except Exception as e:
-            print("error loading subsidence.hds:{0}".format(str(e)))
+            print(f"error loading subsidence.hds:{e!s}")
 
         if as_dict:
             oudic = {}
@@ -694,7 +666,7 @@ class Modflow(BaseModel):
             Path to MODFLOW name file to load.
         version : str, default "mf2005"
             MODFLOW version. Choose one of: "mf2k", "mf2005" (default),
-            "mfnwt", or "mfusg". Note that this can be modified on loading
+            or "mfnwt". Note that this can be modified on loading
             packages unique to different MODFLOW versions.
         exe_name : str, default "mf2005.exe"
             MODFLOW executable name.
@@ -706,8 +678,8 @@ class Modflow(BaseModel):
             List of case insensitive packages to load, e.g. ["bas6", "lpf"].
             One package can also be specified, e.g. "rch". Default is None,
             which attempts to load all files. An empty list [] will not load
-            any additional packages than is necessary. At a minimum, "dis" or
-            "disu" is always loaded.
+            any additional packages than is necessary. At a minimum, "dis" is
+            always loaded.
         forgive : bool, optional
             Option to raise exceptions on package load failure, which can be
             useful for debugging. Default False.
@@ -727,11 +699,11 @@ class Modflow(BaseModel):
         # similar to modflow command: if file does not exist , try file.nam
         namefile_path = os.path.join(model_ws, f)
         if not os.path.isfile(namefile_path) and os.path.isfile(
-            namefile_path + ".nam"
+            f"{namefile_path}.nam"
         ):
             namefile_path += ".nam"
         if not os.path.isfile(namefile_path):
-            raise IOError("cannot find name file: " + str(namefile_path))
+            raise OSError(f"cannot find name file: {namefile_path}")
 
         # Determine model name from 'f', without any extension or path
         modelname = os.path.splitext(os.path.basename(f))[0]
@@ -739,11 +711,7 @@ class Modflow(BaseModel):
         # if model_ws is None:
         #    model_ws = os.path.dirname(f)
         if verbose:
-            print(
-                "\nCreating new model with name: {}\n{}\n".format(
-                    modelname, 50 * "-"
-                )
-            )
+            print(f"\nCreating new model with name: {modelname}\n{50 * '-'}\n")
 
         attribs = mfreadnam.attribs_from_namfile_header(
             os.path.join(model_ws, f)
@@ -755,7 +723,7 @@ class Modflow(BaseModel):
             exe_name=exe_name,
             verbose=verbose,
             model_ws=model_ws,
-            **attribs
+            **attribs,
         )
 
         files_successfully_loaded = []
@@ -790,6 +758,16 @@ class Modflow(BaseModel):
         # update the modflow version
         ml.set_version(version)
 
+        # Impending deprecation warning to switch to using
+        # flopy.mfusg.MfUsg() instead of flopy.modflow.Modflow()
+        if ml.version == "mfusg":
+            warnings.warn(
+                "flopy.modflow.Modflow() for mfusg models has been deprecated, "
+                " and will be removed in the next release. Please switch to using"
+                " flopy.mfusg.MfUsg() instead.",
+                DeprecationWarning,
+            )
+
         # reset unit number for glo file
         if version == "mf2k":
             if "GLOBAL" in ext_pkg_d:
@@ -821,7 +799,7 @@ class Modflow(BaseModel):
                 ml.free_format_input = True
             bas.filehandle.seek(start)
         if verbose:
-            print("ModflowBas6 free format:{0}\n".format(ml.free_format_input))
+            print(f"ModflowBas6 free format:{ml.free_format_input}\n")
 
         # load dis
         dis_key = ext_pkg_d.get("DIS") or ext_pkg_d.get("DISU")
@@ -833,7 +811,7 @@ class Modflow(BaseModel):
         )
         files_successfully_loaded.append(disnamdata.filename)
         if ml.verbose:
-            print("   {:4s} package load...success".format(dis.name[0]))
+            print(f"   {dis.name[0]:4s} package load...success")
         assert ml.pop_key_list.pop() == dis_key
         ext_unit_dict.pop(dis_key).filehandle.close()
 
@@ -890,19 +868,15 @@ class Modflow(BaseModel):
                             files_successfully_loaded.append(item.filename)
                             if ml.verbose:
                                 print(
-                                    "   {:4s} package load...success".format(
-                                        item.filetype
-                                    )
+                                    f"   {item.filetype:4s} package load...success"
                                 )
                         except Exception as e:
                             ml.load_fail = True
                             if ml.verbose:
                                 print(
-                                    "   {:4s} package load...failed".format(
-                                        item.filetype
-                                    )
+                                    f"   {item.filetype:4s} package load...failed"
                                 )
-                                print("   {!s}".format(e))
+                                print(f"   {e!s}")
                             files_not_loaded.append(item.filename)
                     else:
                         if "check" in package_load_args:
@@ -921,30 +895,20 @@ class Modflow(BaseModel):
                         files_successfully_loaded.append(item.filename)
                         if ml.verbose:
                             print(
-                                "   {:4s} package load...success".format(
-                                    item.filetype
-                                )
+                                f"   {item.filetype:4s} package load...success"
                             )
                 else:
                     if ml.verbose:
-                        print(
-                            "   {:4s} package load...skipped".format(
-                                item.filetype
-                            )
-                        )
+                        print(f"   {item.filetype:4s} package load...skipped")
                     files_not_loaded.append(item.filename)
             elif "data" not in item.filetype.lower():
                 files_not_loaded.append(item.filename)
                 if ml.verbose:
-                    print(
-                        "   {:4s} package load...skipped".format(item.filetype)
-                    )
+                    print(f"   {item.filetype:4s} package load...skipped")
             elif "data" in item.filetype.lower():
                 if ml.verbose:
-                    print(
-                        "   {:s} package load...skipped".format(item.filetype)
-                    )
-                    print("      {}".format(os.path.basename(item.filename)))
+                    print(f"   {item.filetype} package load...skipped")
+                    print(f"      {os.path.basename(item.filename)}")
                 if key not in ml.pop_key_list:
                     # do not add unit number (key) if it already exists
                     if key not in ml.external_units:
@@ -955,7 +919,7 @@ class Modflow(BaseModel):
                         )
                         ml.external_output.append(False)
             else:
-                raise KeyError("unhandled case: {}, {}".format(key, item))
+                raise KeyError(f"unhandled case: {key}, {item}")
 
         # pop binary output keys and any external file units that are now
         # internal
@@ -968,30 +932,28 @@ class Modflow(BaseModel):
             except KeyError:
                 if ml.verbose:
                     print(
-                        "\nWARNING:\n    External file unit {} does not "
-                        "exist in ext_unit_dict.".format(key)
+                        f"\nWARNING:\n    External file unit {key} does not "
+                        "exist in ext_unit_dict."
                     )
 
         # write message indicating packages that were successfully loaded
         if ml.verbose:
             print("")
             print(
-                "   The following {} packages were successfully loaded.".format(
-                    len(files_successfully_loaded)
-                )
+                f"   The following {len(files_successfully_loaded)} packages "
+                "were successfully loaded."
             )
             for fname in files_successfully_loaded:
-                print("      " + os.path.basename(fname))
+                print(f"      {os.path.basename(fname)}")
             if len(files_not_loaded) > 0:
                 print(
-                    "   The following {} packages were not loaded.".format(
-                        len(files_not_loaded)
-                    )
+                    f"   The following {len(files_not_loaded)} packages "
+                    "were not loaded."
                 )
                 for fname in files_not_loaded:
-                    print("      " + os.path.basename(fname))
+                    print(f"      {os.path.basename(fname)}")
         if check:
-            ml.check(f="{}.chk".format(ml.name), verbose=ml.verbose, level=0)
+            ml.check(f=f"{ml.name}.chk", verbose=ml.verbose, level=0)
 
         # return model object
         return ml
